==> react-organism-nested-checkboxes-1.1.0.tgz: package/lib/index.js <==
import React, { useState } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import MoleculeCheckboxField from '@s-ui/react-molecule-checkbox-field';
var baseClass = 'sui-OrganismNestedCheckboxes';

var checkItemIsChecked = function checkItemIsChecked(_ref) {
  var checked = _ref.checked;
  return checked === true;
};

var OrganismNestedCheckboxes = function OrganismNestedCheckboxes(_ref2) {
  var id = _ref2.id,
      CheckedIcon = _ref2.checkedIcon,
      IntermediateIcon = _ref2.intermediateIcon,
      HideItemsIcon = _ref2.hideItemsIcon,
      _ref2$items = _ref2.items,
      items = _ref2$items === void 0 ? [] : _ref2$items,
      _ref2$join = _ref2.join,
      join = _ref2$join === void 0 ? false : _ref2$join,
      _ref2$labelParent = _ref2.labelParent,
      labelParent = _ref2$labelParent === void 0 ? '' : _ref2$labelParent,
      _ref2$onChangeItem = _ref2.onChangeItem,
      onChangeItem = _ref2$onChangeItem === void 0 ? function () {} : _ref2$onChangeItem,
      _ref2$onChangeParent = _ref2.onChangeParent,
      onChangeParent = _ref2$onChangeParent === void 0 ? function () {} : _ref2$onChangeParent,
      _ref2$showItems = _ref2.showItems,
      showItemsProp = _ref2$showItems === void 0 ? true : _ref2$showItems,
      ShowItemsIcon = _ref2.showItemsIcon;

  var _useState = useState(showItemsProp),
      showItems = _useState[0],
      setShowItems = _useState[1];

  var showToggleIcons = ShowItemsIcon !== null;
  var isParentFullChecked = items.every(checkItemIsChecked);
  var isParentHalfChecked = !isParentFullChecked && items.some(checkItemIsChecked);
  var isParentFullOrHalfChecked = isParentFullChecked || isParentHalfChecked;
  return React.createElement("ul", {
    className: baseClass
  }, React.createElement("li", null, React.createElement(MoleculeCheckboxField, {
    id: id,
    checked: isParentFullChecked,
    checkedIcon: CheckedIcon,
    intermediate: isParentHalfChecked,
    intermediateIcon: IntermediateIcon,
    label: labelParent,
    onChange: function onChange() {
      return onChangeParent(isParentFullOrHalfChecked);
    },
    toggleIcon: showItems ? HideItemsIcon : ShowItemsIcon,
    toggleIconOnChange: function toggleIconOnChange() {
      return setShowItems(!showItems);
    }
  }), items.length > 0 && showToggleIcons && showItems && React.createElement("ul", {
    className: baseClass + "-list"
  }, items.map(function (item) {
    var _cx;

    var childId = item.id,
        checked = item.checked;
    var listItemClass = baseClass + "-listItem";
    var listItemClassModifier = cx(listItemClass, (_cx = {}, _cx[listItemClass + "--joined"] = join, _cx));
    return React.createElement("li", {
      key: childId,
      className: listItemClassModifier
    }, React.createElement(MoleculeCheckboxField, Object.assign({
      id: childId,
      checked: checked,
      checkedIcon: CheckedIcon,
      intermediateIcon: IntermediateIcon,
      onChange: function onChange(ev) {
        return onChangeItem(ev);
      }
    }, item)));
  }))));
};

OrganismNestedCheckboxes.displayName = 'OrganismNestedCheckboxes';
export default OrganismNestedCheckboxes;

==> react-organism-nested-checkboxes-2.0.0.tgz: package/lib/index.js <==
import React, { useState } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import MoleculeCheckboxField from '@s-ui/react-molecule-checkbox-field';
var baseClass = 'sui-OrganismNestedCheckboxes';

var checkItemIsChecked = function checkItemIsChecked(_ref) {
  var props = _ref.props;
  var checked = props.checked;
  return checked === true;
};

var OrganismNestedCheckboxes = function OrganismNestedCheckboxes(_ref2) {
  var children = _ref2.children,
      id = _ref2.id,
      CheckedIcon = _ref2.checkedIcon,
      IntermediateIcon = _ref2.intermediateIcon,
      HideItemsIcon = _ref2.hideItemsIcon,
      _ref2$join = _ref2.join,
      join = _ref2$join === void 0 ? false : _ref2$join,
      _ref2$labelParent = _ref2.labelParent,
      labelParent = _ref2$labelParent === void 0 ? '' : _ref2$labelParent,
      _ref2$onChangeItem = _ref2.onChangeItem,
      onChangeItem = _ref2$onChangeItem === void 0 ? function () {} : _ref2$onChangeItem,
      _ref2$onChangeParent = _ref2.onChangeParent,
      onChangeParent = _ref2$onChangeParent === void 0 ? function () {} : _ref2$onChangeParent,
      _ref2$onClickParent = _ref2.onClickParent,
      onClickParent = _ref2$onClickParent === void 0 ? function () {} : _ref2$onClickParent,
      _ref2$showItems = _ref2.showItems,
      showItemsProp = _ref2$showItems === void 0 ? true : _ref2$showItems,
      ShowItemsIcon = _ref2.showItemsIcon;

  var _useState = useState(showItemsProp),
      showItems = _useState[0],
      setShowItems = _useState[1];

  var showToggleIcons = ShowItemsIcon !== null;
  var isParentChecked = children === null || children === void 0 ? void 0 : children.every(checkItemIsChecked);
  var isParentIntermediate = !isParentChecked && (children === null || children === void 0 ? void 0 : children.some(checkItemIsChecked));
  return React.createElement("ul", {
    className: baseClass
  }, React.createElement("li", {
    onClick: onClickParent
  }, React.createElement(MoleculeCheckboxField, {
    id: id,
    checked: isParentChecked,
    checkedIcon: CheckedIcon,
    intermediate: isParentIntermediate,
    intermediateIcon: IntermediateIcon,
    label: labelParent,
    onChange: onChangeParent,
    toggleIcon: showItems ? HideItemsIcon : ShowItemsIcon,
    toggleIconOnChange: function toggleIconOnChange() {
      return setShowItems(!showItems);
    }
  }), (children === null || children === void 0 ? void 0 : children.length) > 0 && showToggleIcons && showItems && React.createElement("ul", {
    className: baseClass + "-list"
  }, children === null || children === void 0 ? void 0 : children.map(function (child) {
    var _cx;

    var props = child.props;
    var childId = props.id;
    var listItemClass = baseClass + "-listItem";
    var listItemClassModifier = cx(listItemClass, (_cx = {}, _cx[listItemClass + "--joined"] = join, _cx));
    return React.createElement("li", {
      key: childId,
      className: listItemClassModifier
    }, child);
  }))));
};

OrganismNestedCheckboxes.displayName = 'OrganismNestedCheckboxes';
export default OrganismNestedCheckboxes;
